package main

import (
	"encoding/json"
	"fmt"
	"os"
	"strings"
)

func main() {

	//ask the user for the input file
	fmt.Println("Please enter the absolute path of the input file:")
	var filePath string
	_, err := fmt.Scanln(&filePath)
	if err != nil {
		return
	}

	//ask the user for the output file name
	fmt.Println("Please enter the name of the output file:")
	var outputFileName string
	_, err = fmt.Scanln(&outputFileName)
	if err != nil {
		return
	}

	//open file
	vaultImport, err := os.ReadFile(filePath)
	if err != nil {
		fmt.Println(err)
	}

	//convert vaultImport into a struct
	var customerVault CustomerVault
	err = json.Unmarshal(vaultImport, &customerVault)
	if err != nil {
		fmt.Println(err)
	}

	ConvertToCSV(customerVault, outputFileName)
}

func ConvertToCSV(customerVault CustomerVault, outputFileName string) {
	//create a new file
	file, err := os.Create(outputFileName)
	if err != nil {
		fmt.Println(err)
	}
	defer file.Close()

	var sb strings.Builder

	//write the header
	sb.WriteString("CustomerVaultID,BillingID,BillingFirstName,BillingLastName,BillingCompany,BillingEmail,BillingPhone,BillingFax,BillingAddress1,BillingAddress2,BillingCity,BillingState,BillingPostalCode,BillingCountry,BillingPaymentMethod,BillingAccountNumber, BillingAccountExpiration,BillingRouting,BillingCheckName,BillingCheckAccountHolderType,BillingCheckAccountType,BillingCheckSecCode\n")

	//iterate through each record in customerVault and write to file as a CSV
	for _, record := range customerVault {
		for _, billingRecord := range record.BillingRecords {
			sb.WriteString(record.CustomerVaultID + ",")
			//format the billing records into a string using the stringbuilder
			sb.WriteString(fmt.Sprintf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,", billingRecord.ID, billingRecord.FirstName, billingRecord.LastName, billingRecord.Company, billingRecord.Email, billingRecord.Phone, billingRecord.Fax, billingRecord.Address1, billingRecord.Address2, billingRecord.City, billingRecord.State, billingRecord.PostalCode, billingRecord.Country, billingRecord.PaymentMethod, billingRecord.AccountNumber, billingRecord.AccountExpiration, billingRecord.Routing, billingRecord.CheckName, billingRecord.CheckAccountHolderType, billingRecord.CheckAccountType, billingRecord.CheckSecCode))
			sb.WriteString("\n")
		}
	}
	//write the stringbuilder to the file
	file.WriteString(sb.String())

}
